================
edx-prefectutils
================






A utility code written by edX specifically for edX Prefect Flows. It assists writing in edX Prefect Flows.



Features
--------

* TODO

PyPI Package Release
--------------------
- This repository publishes packages on PyPI, when you update this repository make sure to create a new release so latest changes would be published on PyPI and become available for use.
- Bump the `version`_ to match the version that will be released. Once the pull request with the updated version is merged into master, create a new release from GitHub Web UI, using the same version number. You can refer to `How to create GitHub release`_ for more information on this process.
- `edx-prefectutils PyPI`_ package is used in `prefect-flows`_ repository, you will have to update edx-prefectutils package version in `requirements`_ so it will pick latest PyPI package version.

.. _`version`: https://github.com/edx/edx-prefectutils/blob/master/edx_prefectutils/__init__.py#L5
.. _`How to create GitHub release`: https://docs.github.com/en/github/administering-a-repository/releasing-projects-on-github/managing-releases-in-a-repository
.. _`edx-prefectutils PyPI`: https://pypi.org/project/edx-prefectutils/
.. _`prefect-flows`: https://github.com/edx/prefect-flows
.. _`requirements`: https://github.com/edx/prefect-flows/blob/master/requirements.txt#L7



Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
